@@ -12,9 +12,10 @@
 #' @param parameters.initial Initial values for P, S or K search as a vector, ex. c(P=29, S=-0.3)
 #' @param fixed.parameters Parameters that will not be changed
 #' @param males.freq If TRUE data are shown as males frequency
-#' @param equation Could be "logistic", "Hill", "A-logistic", "Hulin", "Double-A-logistic", "flexit" or "GSD"
+#' @param equation Can be "logistic", "Hill", "A-logistic", "Hulin", "Double-A-logistic", "flexit", "GSD", "logit", "probit"
 #' @param replicate.CI Number of replicates to estimate confidence intervals
 #' @param replicate.NullDeviance Number of replicates to estimate null distribution of deviance
+#' @param SE If FALSE, does not estimate SE of parameters. Can be use when something wrong happens.
 #' @param range.CI The range of confidence interval for estimation, default=0.95
 #' @param print Should the results be printed at screen? TRUE (default) or FALSE
 #' @param control List of parameters used in optim.
@@ -27,7 +28,7 @@
 #' For other models, TRT is calculated numerically.\cr
 #' The basic model is logistic one. This model has the particularity to have a symmetric shape around P.\cr
 #' The other models have been built to alleviate this constraint. Hill and A-logistic models can be asymmetric, but it is impossible to control independently the low and high transitions.\cr
-#' Hulin model is assymmetric but the control of asymmetry is difficult to manage./cr
+#' Hulin model is assymmetric but the control of asymmetry is difficult to manage.\cr
 #' If asymmetric model is selected, it is always better to use flexit model.
 #' \deqn{if dose < P then (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(-1/K1)}{if dose < P then (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(-1/K1)}
 #' \deqn{if dose > P then 1-((1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2)}{if dose > P then 1-((1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2)}
@@ -37,6 +38,7 @@
 #' @references Girondot, M. 1999. Statistical description of temperature-dependent sex determination using maximum likelihood. Evolutionary Ecology Research, 1, 479-486.
 #' @references Godfrey, M.H., Delmas, V., Girondot, M., 2003. Assessment of patterns of temperature-dependent sex determination using maximum likelihood model selection. Ecoscience 10, 265-272.
 #' @references Hulin, V., Delmas, V., Girondot, M., Godfrey, M.H., Guillon, J.-M., 2009. Temperature-dependent sex determination and global change: are some species at greater risk? Oecologia 160, 493-506.
+#' @references Abreu-Grobois, F.A., Morales-Mérida, B.A., Hart, C.E., Guillon, J.-M., Godfrey, M.H., Navarro, E., Girondot, M., 2020. Recent advances on the estimation of the thermal reaction norm for sex ratios. PeerJ 8, e8451.
 #' @family Functions for temperature-dependent sex determination
 #' @examples
 #' \dontrun{
@@ -240,23 +242,36 @@
 #' @export
 
 
-tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL, 
-                temperatures=NULL, 
-                durations=NULL,
-                l=0.05, parameters.initial=c(P=NA, S=-2, K=0, K1=1, K2=0), 
-                males.freq=TRUE, 
-                fixed.parameters=NULL, 
-                equation="logistic", replicate.CI=10000, range.CI=0.95, 
-                replicate.NullDeviance=1000, 
-                control=list(maxit=1000),
-                print=TRUE) {
+tsd <- function(df=NULL                                            , 
+                males=NULL                                         , 
+                females=NULL                                       , 
+                N=NULL                                             , 
+                temperatures=NULL                                  , 
+                durations=NULL                                     ,
+                l=0.05                                             , 
+                parameters.initial=c(P=NA, S=-2, K=0, K1=1, K2=0)  , 
+                males.freq=TRUE                                    , 
+                fixed.parameters=NULL                              , 
+                equation="logistic"                                , 
+                replicate.CI=10000                                 , 
+                range.CI=0.95                                      , 
+                SE=TRUE                                            , 
+                replicate.NullDeviance=1000                        , 
+                control=list(maxit=1000)                           ,
+                print=TRUE                                         ) {
   
-  # df=NULL; males=NULL; females=NULL; N=NULL; temperatures=NULL; durations=NULL; l=0.05; parameters.initial=c(P=NA, S=-0.5, K=0, K1=1, K2=0); males.freq=TRUE; fixed.parameters=NULL; equation="logistic"; replicate.CI=10000; range.CI=0.95; print=TRUE; control=list(maxit=1000); replicate.NullDeviance=1000
+  # df=NULL; males=NULL; females=NULL; N=NULL; temperatures=NULL; durations=NULL; l=0.05; parameters.initial=c(P=NA, S=-0.5, K=0, K1=1, K2=0); males.freq=TRUE; fixed.parameters=NULL; equation="logistic"; replicate.CI=10000; range.CI=0.95; SE=TRUE;print=TRUE; control=list(maxit=1000); replicate.NullDeviance=1000
   # CC_AtlanticSW <- subset(DatabaseTSD, RMU=="Atlantic, SW" & Species=="Caretta caretta" & Sexed!=0)
   # males=CC_AtlanticSW$Males; females=CC_AtlanticSW$Females; temperatures=CC_AtlanticSW$Incubation.temperature-CC_AtlanticSW$Correction.factor; equation="logistic"
   # parameters.initial = c(P=29.19); fixed.parameters = c(S=-0.21)
   equation <- tolower(equation)
   
+  equation <- match.arg(equation, 
+                        choices = c("logistic", "hill", "a-logistic", "hulin", 
+                                    "double-a-logistic", "flexit", "gsd", 
+                                    "probit", "logit"), 
+                        several.ok = FALSE)
+  
   if (!is.null(df)) {
     if (class(df)!="data.frame" & class(df)!="matrix") {
       stop("df parameter must be a data.frame or a matrix")
@@ -314,23 +329,26 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
     stop("A temperature or duration must be provided for each experiment")
   }
   
-  equation <- match.arg(equation, choices = c("gsd", "hulin", "logistic", "hill", "flexit", "a-logistic", "double-a-logistic"))
-  
-  
   if (all(males * females == 0)) {
     warning("At least one incubation temperature should produce mixed sex ratio. Use MCMC rather.")
   }
   
   
   if (equation=="gsd") {
+    value <- -sum(dbinom(x=males, size=males+females, prob=0.5, log=TRUE))
     result <- list(par = NULL, SE=NULL, hessian=NULL, 
                    TRT=NULL,
                    SE_TRT=NULL,
                    message=NULL,
                    convergence=0,
                    counts=NULL,
-                   value=-sum(dbinom(x=males, size=males+females, prob=0.5, log=TRUE)),
-                   AIC=-2*sum(dbinom(x=males, size=males+females, prob=0.5, log=TRUE)))
+                   value = value,
+                   AIC= 2*value + 2*0, 
+                   AICc= 2*value + (2*0*(0+1))/(sum(N)-0-1), 
+                   BIC= 2*value + 0
+                   )
+
+    
     #    limit.low.TRT <- min(temperatures)
     #    limit.high.TRT <- max(temperatures)	
   } else {
@@ -365,7 +383,7 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
       ppi <- ppi[which(names(ppi)!="K2")]
     }
     
-   par <-  ppi
+    par <-  ppi
     
     repeat {
       # result  <- optim(par, embryogrowth:::.tsd_fit, fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, equation=equation, method="BFGS", hessian=TRUE, control = list(maxit=1000))
@@ -380,12 +398,16 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
     
     par <- c(result$par, fixed.parameters)
     
-    rh <- SEfromHessian(result$hessian, hessian=TRUE)
-    result$SE <- rh$SE
-    result$hessian <- rh$hessian
+    if (SE) {
+      rh <- SEfromHessian(result$hessian, hessian=TRUE)
+      result$SE <- rh$SE
+    }
+    result$hessian <- result$hessian
     result$AIC <- 2*result$value+2*length(par)
-    result$AICc <- result$AIC +(2*length(par)*(length(par)+1))/(length(males)-length(par)-1)
-    result$BIC <- 2*result$value+ length(par)*log(length(males))
+    # Correction le 21/10/2020
+    result$AICc <- result$AIC +(2*length(par)*(length(par)+1))/(sum(N)-length(par)-1)
+    # Correction le 21/10/2020
+    result$BIC <- 2*result$value+ length(par)*log(sum(N))
   }
   
   
@@ -399,10 +421,13 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
   result$males.freq <- males.freq
   result$fixed.parameters <- fixed.parameters
   result$type <- ifelse(IP, "duration", "temperature")
+  
+  
+  
   result$deviance <- -2*(-result$value - sum(dbinom(x = males, size=N, 
                                                     prob = males/N, log = TRUE)))
-  
-  result$df <- length(result$males) - length(result$par)
+  # degrees of freedom calculated from the difference of the number of parameters in the saturated and the fitted model. 
+  result$df <- length(males) - length(result$par)
   result$pvalue <- pchisq(q=result$deviance, df=result$df, lower.tail = FALSE)
   
   if (equation != "gsd") {
@@ -421,7 +446,7 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
                                                                   equation=equation)
   result$predictMaleFrequency <- probtheor
   
-  if (replicate.NullDeviance != 0) {
+  if (!is.null(replicate.NullDeviance) & (replicate.NullDeviance != 0)) {
     pt <- NULL
     # Bug correct 2020-01-11: change 1000 to replicate.NullDeviance
     for (i in 1:replicate.NullDeviance) {
@@ -444,17 +469,17 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
   
   if (equation!="gsd" & print) {
     if (any(colnames(o$P_TRT_quantiles)=="PT")) {
-    if (!is.null(replicate.CI)) {
-      print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"]))))
-      print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"]))))
-      print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"]))))
-      print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"]))))
-    } else {
-      print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"])))
-      print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"])))
-      print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"])))
-      print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"])))
-    }
+      if (!is.null(replicate.CI) | (replicate.CI == 0)) {
+        print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"]))))
+        print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"]))))
+        print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"]))))
+        print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"]))))
+      } else {
+        print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"])))
+        print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"])))
+        print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"])))
+        print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"])))
+      }
     } else {
       if (!is.null(replicate.CI)) {
         print(paste0("The lower pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"]))))
